/***************************************************************************
 *   Copyright (C) 2005 by Joel R. Voss                                    *
 *   jvoss@myuw.net                                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <stdio.h>
#include <string.h>
#include "cli.h"

// Use the Command-line Interface
// The cli is a quick and dirty interface to the guts of the cat.
// It is based on nothing, but can use scanf or something.

int cli_render()
{
	// TODO: Draw the cat in some form. Probably debug text or rpg-style.
	printf("Data: ");
	printf("(%i, %i) ", cat2->current_x, cat2->current_y);
	printf("\n");
	RobotCat_update(cat2);
	return 0;
}

void cli_usage()
{
	printf("Robot Cat cli\n");
	printf("  help:     This screen.\n");
	printf("  quit:     Exit.\n");
	printf("  start:    Start (test only).\n");
	printf("  temp:     Input temperature.\n");
	printf("  motion:   Input motion.\n");
	printf("  audio:    Input audio.\n");
	printf("  good:     Cause good memory.\n");
	printf("  bad:      Cause bad  memory.\n");
	printf("  food:     Give cat food.\n");
	printf("  sleep:    Put cat to sleep.\n");
	printf("  enemy:    Make cat angry.\n");
	printf("  friendly: Make cat happy.\n");
	printf("  human:    Show cat a human.\n");
}

int cli_input()
{
	// Read input depending on if we care.
	printf("# ");
	char command[128];
	
	// Ctrl-D ends up not putting any data into command.
	command[0] = 0;
	fgets(command, 127, stdin);
	
	// Delete the newline because it's abhorrant.
	char *newline = strchr(command, '\n');
	if(*newline == '\n') *newline = 0;
	
	// Ctrl-D exits.
	if(strcmp("quit", command) == 0 || command[0] == 0)
	{
		// Exit program.
		printf("\n");
		return 0;
	}
	else if(strcmp("help", command) == 0)
	{
		// Show help.
		cli_usage();
	}
	else if(strcmp("sleep", command) == 0)
	{
		// Give Sleep.
		RobotCat_input(cat2, sleep, 1);
	}
	else if(strcmp("food", command) == 0)
	{
		// Give Food.
		RobotCat_input(cat2, food, 1);
	}
	else if(strcmp("start", command) == 0)
	{
		// Start (test only).
		RobotCat_input(cat2, start, 1);
	}
	else if(strcmp("temp", command) == 0)
	{
		// Input temperature.
		RobotCat_input(cat2, temperature, 1);
	}
	else if(strcmp("motion", command) == 0)
	{
		// Input motion.
		RobotCat_input(cat2, motion, 1);
	}
	else if(strcmp("audio", command) == 0)
	{
		// Input audio.
		RobotCat_input(cat2, audio, 1);
	}
	else if(strcmp("good", command) == 0)
	{
		// Cause good memory.
		RobotCat_input(cat2, good, 1);
	}
	else if(strcmp("bad", command) == 0)
	{
		// Cause bad  memory.
		RobotCat_input(cat2, bad, 1);
	}
	else if(strcmp("enemy", command) == 0)
	{
		// Make cat angry.
		RobotCat_input(cat2, enemy, 1);
	}
	else if(strcmp("friendly", command) == 0)
	{
		// Make cat happy.
		RobotCat_input(cat2, friendly, 1);
	}
	else if(strcmp("human", command) == 0)
	{
		// Show cat a human.
		RobotCat_input(cat2, human, 1);
	}
	printf("Your input: %s;\n", command);
	return 1;
}

int cli_main(int argc, char *argv[], RobotCat *cat_init)
{
	cat2 = cat_init;

	while(true)
	{
		// Draw the interface.
		cli_render();
	
		// Get input. If it ever returns false, end.
		if(!cli_input())
			break;
	}
	return 0;
}
